"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * An issued currency on the XRP Ledger
 * @see: https://xrpl.org/currency-formats.html#currency-codes
 */
class XrpCurrency {
    /**
     * @param name 3 character ASCII code
     * @param code 160 bit currency code. 20 bytes
     */
    constructor(name, code) {
        this.name = name;
        this.code = code;
    }
    /**
     * Constructs an XrpCurrency from a Currency.
     *
     * @param currency a Currency (protobuf object) whose field values will be used
     *                 to construct an XRPCurrency
     * @returns an XrpCurrency with its fields set via the analogous protobuf fields.
     * @see https://github.com/ripple/rippled/blob/develop/src/ripple/proto/org/xrpl/rpc/v1/amount.proto#L41
     */
    static from(currency) {
        return new XrpCurrency(currency.getName(), currency.getCode_asU8());
    }
}
exports.default = XrpCurrency;
//# sourceMappingURL=xrp-currency.js.map