"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Represents a signer of a transaction on the XRP Ledger.
 * @see: https://xrpl.org/transaction-common-fields.html#signers-field
 */
class XrpSigner {
    /**
     * @param account The address associated with this signature, as it appears in the SignerList.
     * @param signingPublicKey The public key used to create this signature.
     * @param transactionSignature A signature for this transaction, verifiable using the SigningPubKey.
     */
    constructor(account, signingPublicKey, transactionSignature) {
        this.account = account;
        this.signingPublicKey = signingPublicKey;
        this.transactionSignature = transactionSignature;
    }
    /**
     * Constructs an XrpSigner from a Signer.
     *
     * @param signer a Signer (protobuf object) whose field values will be used
     *               to construct an XrpSigner
     * @return an XrpSigner with its fields set via the analogous protobuf fields.
     * @see https://github.com/ripple/rippled/blob/develop/src/ripple/proto/org/xrpl/rpc/v1/transaction.proto#L90
     */
    static from(signer) {
        var _a, _b, _c, _d;
        const account = (_b = (_a = signer.getAccount()) === null || _a === void 0 ? void 0 : _a.getValue()) === null || _b === void 0 ? void 0 : _b.getAddress();
        const signingPublicKey = (_c = signer.getSigningPublicKey()) === null || _c === void 0 ? void 0 : _c.getValue_asU8();
        const transactionSignature = (_d = signer
            .getTransactionSignature()) === null || _d === void 0 ? void 0 : _d.getValue_asU8();
        return new XrpSigner(account, signingPublicKey, transactionSignature);
    }
}
exports.default = XrpSigner;
//# sourceMappingURL=xrp-signer.js.map