/**
 * Types of errors that originate from interacting with XRPL.
 */
export declare enum XrpErrorType {
    InvalidInput = 0,
    PaymentConversionFailure = 1,
    MalformedResponse = 2,
    SigningError = 3,
    Unknown = 4,
    XAddressRequired = 5
}
/**
 * Represents errors thrown by XRP components of the Xpring SDK.
 */
export default class XrpError extends Error {
    readonly errorType: XrpErrorType;
    /**
     * An X-Address is required to use the requested functionality.
     */
    static xAddressRequired: XrpError;
    /**
     * A payment transaction can't be converted to an XrpTransaction.
     */
    static paymentConversionFailure: XrpError;
    /**
     * The response was in an unexpected format.
     */
    static malformedResponse: XrpError;
    /**
     * There was a problem signing the transaction.
     */
    static signingError: XrpError;
    /**
     * @param errorType The type of error.
     * @param message The error message.
     */
    constructor(errorType: XrpErrorType, message?: string | undefined);
}
