"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.XrpErrorType = void 0;
/**
 * Types of errors that originate from interacting with XRPL.
 */
var XrpErrorType;
(function (XrpErrorType) {
    XrpErrorType[XrpErrorType["InvalidInput"] = 0] = "InvalidInput";
    XrpErrorType[XrpErrorType["PaymentConversionFailure"] = 1] = "PaymentConversionFailure";
    XrpErrorType[XrpErrorType["MalformedResponse"] = 2] = "MalformedResponse";
    XrpErrorType[XrpErrorType["SigningError"] = 3] = "SigningError";
    XrpErrorType[XrpErrorType["Unknown"] = 4] = "Unknown";
    XrpErrorType[XrpErrorType["XAddressRequired"] = 5] = "XAddressRequired";
})(XrpErrorType = exports.XrpErrorType || (exports.XrpErrorType = {}));
/**
 * Represents errors thrown by XRP components of the Xpring SDK.
 */
class XrpError extends Error {
    /**
     * @param errorType The type of error.
     * @param message The error message.
     */
    constructor(errorType, message = undefined) {
        super(message);
        this.errorType = errorType;
    }
}
exports.default = XrpError;
/**
 * An X-Address is required to use the requested functionality.
 */
XrpError.xAddressRequired = new XrpError(XrpErrorType.XAddressRequired, 'Please use the X-Address format. See: https://xrpaddress.info/.');
/**
 * A payment transaction can't be converted to an XrpTransaction.
 */
XrpError.paymentConversionFailure = new XrpError(XrpErrorType.PaymentConversionFailure, 'Could not convert payment transaction: (transaction). Please file a bug at https://github.com/xpring-eng/Xpring-JS/issues');
/**
 * The response was in an unexpected format.
 */
XrpError.malformedResponse = new XrpError(XrpErrorType.MalformedResponse, 'The response from the remote service was malformed or in an unexpected format');
/**
 * There was a problem signing the transaction.
 */
XrpError.signingError = new XrpError(XrpErrorType.SigningError, 'There was an error signing the transaction');
//# sourceMappingURL=xrp-error.js.map